# nautilus

[![Join the chat at https://gitter.im/nautilus/nautilus](https://badges.gitter.im/nautilus/nautilus.svg)](https://gitter.im/nautilus/nautilus?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/nautilus/nautilus.svg?branch=master)](https://travis-ci.org/nautilus/nautilus)
[![Coverage Status](https://coveralls.io/repos/github/nautilus/nautilus/badge.svg?branch=master)](https://coveralls.io/github/nautilus/nautilus?branch=master)

Nautilus is a framework for event-driven microservices that attempts to provide
extendible implementations of common aspects of a moden web application so that you can focus
on what you do best: building awesome, scalable services. Some of these features include:

* Distributed authentication
* Message passing
* Couple-free service joins
* Service API versioning (coming soon!)
* A flexible GraphQL API that adapts as services come online
* Distributed/remote database administration (coming soon!)

Full documentation is hosted [here](http://nautilus.github.io/nautilus/).

## Requirements
* >= Python 3.5
* Kafka
